@@ -7,7 +7,7 @@ use boolean qw(true);
 use HTML::Entities qw(decode_entities);
 use HTML::Parser ();
 
-our $VERSION = '0.04';
+our $VERSION = '0.01';
 
 my (@tags, @stack);
 
@@ -18,12 +18,10 @@ sub _init_parser
     my $parser = HTML::Parser->new(
         api_version => 3,
         start_h     => [ \&_start_tag, 'tagname,attr,attrseq' ],
-        text_h      => [ \&_text_tag,  'text'                 ],
+        text_h      => [ \&_text_tag,  'dtext'                ],
         end_h       => [ \&_end_tag,   'tagname'              ],
     );
 
-   $parser->attr_encoded(true);
-
     return $parser;
 }
 
@@ -36,7 +34,7 @@ sub _parse_html
 
     undef @stack;
 
-    return unless @tags;
+    return unless scalar @tags;
 
     @$html = @tags;
     undef @tags;
@@ -58,18 +56,18 @@ sub _start_tag
 
 sub _text_tag
 {
-    my ($text) = @_;
+    my ($dtext) = @_;
 
-    return unless @stack;
+    return unless scalar @stack;
 
-    $stack[-1]->{text} = $text;
+    $stack[-1]->{text} = $dtext;
 }
 
 sub _end_tag
 {
     my ($tagname) = @_;
 
-    return unless @stack;
+    return unless scalar @stack;
 
     if ($stack[-1]->{name} eq $tagname) {
         push @tags, {
@@ -92,7 +90,7 @@ sub _rewrite_tags
         foreach my $html (@{$fields->{_html}->{$field}}) {
             foreach my $tag (keys %$html) {
                 my @tagnames;
-                if (%{$html->{$tag}->{attr}}) {
+                if (scalar keys %{$html->{$tag}->{attr}}) {
                     foreach my $attr (keys %{$html->{$tag}->{attr}}) {
                         if (exists $self->{Tag_handlers}->{"$tag $attr"}) {
                             push @tagnames, "$tag $attr";
@@ -118,12 +116,9 @@ sub _rewrite_tags
                                 $subst =~ s/\$$place_holder/$replacement/;
                             }
                             my $re = $self->_subst_pattern($html, $tag);
-                            if (defined $html->{$tag}->{text}) {
-                                $fields->{$field} =~ s{$re}{$subst};
-                            }
-                            else {
-                                $fields->{$field} =~ s{$re}{$1};
-                            }
+                            my ($text) = $fields->{$field} =~ $re;
+                            my $replace = defined $html->{$tag}->{text} ? $subst : $text;
+                            $fields->{$field} =~ s{$re}{$replace};
                         }
                     }
                 }
@@ -195,7 +190,7 @@ sub _subst_pattern
     my $self = shift;
     my ($html, $tag) = @_;
 
-    if (@{$html->{$tag}->{attrseq}}) {
+    if (scalar @{$html->{$tag}->{attrseq}}) {
         my $attr = join ' ',
           map "${_}=\"$html->{$tag}->{attr}->{$_}\"",
           @{$html->{$tag}->{attrseq}};
